/*
 * talkatu
 * Copyright (C) 2017-2019 Gary Kramlich <grim@reaperworld.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

#if !defined(TALKATU_GLOBAL_HEADER_INSIDE) && !defined(TALKATU_COMPILATION)
#error "only <talkatu.h> may be included directly"
#endif

#ifndef TALKATU_MESSAGE_H
#define TALKATU_MESSAGE_H

#include <glib.h>
#include <glib-object.h>

#include <gtk/gtk.h>

typedef enum _TalkatuContentType /*< prefix=TALKATU_CONTENT_TYPE,underscore_name=TALKATU_CONTENT_TYPE >*/
{
	TALKATU_CONTENT_TYPE_PLAIN =  0,
	TALKATU_CONTENT_TYPE_PANGO,
	TALKATU_CONTENT_TYPE_HTML,
	TALKATU_CONTENT_TYPE_MARKDOWN,
} TalkatuContentType;

G_BEGIN_DECLS

#define TALKATU_TYPE_MESSAGE            (talkatu_message_get_type())

G_DECLARE_INTERFACE(TalkatuMessage, talkatu_message, TALKATU, MESSAGE, GObject)

struct _TalkatuMessageInterface {
	/*< private >*/
	GTypeInterface parent;

	/*< private >*/
	gpointer reserved[4];
};

guint64 talkatu_message_get_id(TalkatuMessage *message);
void talkatu_message_set_id(TalkatuMessage *message, guint64 id);

GDateTime *talkatu_message_get_timestamp(TalkatuMessage *message);
void talkatu_message_set_timestamp(TalkatuMessage *message, GDateTime *timestamp);

TalkatuContentType talkatu_message_get_content_type(TalkatuMessage *message);

gchar *talkatu_message_get_author(TalkatuMessage *message);
void talkatu_message_set_author(TalkatuMessage *message, const gchar *author);

gchar *talkatu_message_get_contents(TalkatuMessage *message);
void talkatu_message_set_contents(TalkatuMessage *message, const gchar *contents);

gboolean talkatu_message_get_edited(TalkatuMessage *message);
void talkatu_message_set_edited(TalkatuMessage *message, gboolean edited);

G_END_DECLS

#endif /* TALKATU_MESSAGE_H */
